#!/usr/bin/env bash

#####################################################################################################################
# Functions for handling filesystem operations for DT platform
# Author: J.R.Berlin
#####################################################################################################################

# load base library to be used in DT machines, for DT machines it needs to be the Architecture choosen for the experiment
#shellcheck disable=SC1090  #as only functions are loaded
. "${PROJDIR}/platforms/${HPCARCH}/filesystem.sh"

#####################################################################################################################
# any override from the common libraries defined in filesystem.sh or new function goes here
#####################################################################################################################

#####################################################################################################################
# Globals:
# ROOTDIR, PROJDEST, PROJDIR
# Arguments:
#   None
# Returns:
#   None
# Purpose: send the initial set of libraries used by the synchronize job in order to be able to run
#
#####################################################################################################################
function copy_platform_environment_to_host() {
  echo "DT host doesn´t need to transfer the platforms files"
}

#####################################################################################################################
# Globals:
# HPCARCH
# Arguments:
#   None
# Returns:
#   None
# Purpose: Prepare common paths for transfer for the dt machine
#
#####################################################################################################################
function setup_paths_transfer_mn5_transfer_node() {
  "setup_paths_transfer_${HPCARCH}"
}

#####################################################################################################################
# Globals:
# ROOTDIR, EXPID, EXPID, HPCUSER, HPCHOST, HPCPROJ
# Arguments:
#   None
# Returns:
#   cmor_dataset_version_remote
# Purpose: check if the file CMOR_VERSION_DATASET is present on HPC
#####################################################################################################################
function check_cmor_dataset_version_remote(){
  [[ ! -f ${ROOTDIR}/LOG_${EXPID}/${EXPID}_CMOR_DATASETVERSION ]] && export cmor_dataset_version_remote="FALSE"
}

#####################################################################################################################
# Globals:
# CMORDIR
# Arguments:
#   None
# Returns:
#   cmor_dataset_version
# Purpose: read the  cmor_dataset_version in esarchive
#####################################################################################################################

function get_esarchive_cmor_dataset_version(){
  cmor_dataset_version=$(find "${CMORDIR}"/*/*/*/*/*/*/ -mindepth 1 -maxdepth 1 -type d -printf '%f\n' | sort -u)
}

#####################################################################################################################
# Globals:
# cmor_dataset_version, ROOTDIR, EXPID
# Arguments:
#   None
# Returns:
#   None
# Purpose: write the file ${EXPID}_CMOR_DATASETVERSION on the HPC's scratch
#####################################################################################################################

function write_cmor_dataset_version(){
  create_directory "${ROOTDIR}/LOG_${EXPID}" "bsc32"
  echo "${cmor_dataset_version}" > "${ROOTDIR}/LOG_${EXPID}/${EXPID}_CMOR_DATASETVERSION"
}
